@@ -98,6 +98,8 @@ class DnspodClient(AbstractClient):
     def CreateDomain(self, request):
         """添加域名
 
+        备注：该接口不支持添加子域名。
+
         :param request: Request instance for CreateDomain.
         :type request: :class:`tencentcloud.dnspod.v20210323.models.CreateDomainRequest`
         :rtype: :class:`tencentcloud.dnspod.v20210323.models.CreateDomainResponse`
@@ -164,6 +166,29 @@ class DnspodClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateDomainCustomLine(self, request):
+        """创建域名的自定义线路
+
+        :param request: Request instance for CreateDomainCustomLine.
+        :type request: :class:`tencentcloud.dnspod.v20210323.models.CreateDomainCustomLineRequest`
+        :rtype: :class:`tencentcloud.dnspod.v20210323.models.CreateDomainCustomLineResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateDomainCustomLine", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateDomainCustomLineResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateDomainGroup(self, request):
         """创建域名分组
 
@@ -187,8 +212,78 @@ class DnspodClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateDomainsAnalyticsFile(self, request):
+        """批量导出域名解析量
+
+        :param request: Request instance for CreateDomainsAnalyticsFile.
+        :type request: :class:`tencentcloud.dnspod.v20210323.models.CreateDomainsAnalyticsFileRequest`
+        :rtype: :class:`tencentcloud.dnspod.v20210323.models.CreateDomainsAnalyticsFileResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateDomainsAnalyticsFile", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateDomainsAnalyticsFileResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def CreateLineGroup(self, request):
+        """创建域名的线路分组
+
+        :param request: Request instance for CreateLineGroup.
+        :type request: :class:`tencentcloud.dnspod.v20210323.models.CreateLineGroupRequest`
+        :rtype: :class:`tencentcloud.dnspod.v20210323.models.CreateLineGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateLineGroup", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateLineGroupResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def CreateLineGroupCopy(self, request):
+        """复制域名的线路分组
+
+        :param request: Request instance for CreateLineGroupCopy.
+        :type request: :class:`tencentcloud.dnspod.v20210323.models.CreateLineGroupCopyRequest`
+        :rtype: :class:`tencentcloud.dnspod.v20210323.models.CreateLineGroupCopyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateLineGroupCopy", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateLineGroupCopyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateRecord(self, request):
         """添加记录
+        备注：新添加的解析记录存在短暂的索引延迟，如果查询不到新增记录，请在 30 秒后重试
 
         :param request: Request instance for CreateRecord.
         :type request: :class:`tencentcloud.dnspod.v20210323.models.CreateRecordRequest`
@@ -279,6 +374,76 @@ class DnspodClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateSubDomainsAnalyticsFile(self, request):
+        """批量导出子域名解析量
+
+        :param request: Request instance for CreateSubDomainsAnalyticsFile.
+        :type request: :class:`tencentcloud.dnspod.v20210323.models.CreateSubDomainsAnalyticsFileRequest`
+        :rtype: :class:`tencentcloud.dnspod.v20210323.models.CreateSubDomainsAnalyticsFileResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateSubDomainsAnalyticsFile", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateSubDomainsAnalyticsFileResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def CreateSubdomainValidateTXTValue(self, request):
+        """创建添加子域名 Zone 域解析时所需要的 TXT 记录值
+
+        :param request: Request instance for CreateSubdomainValidateTXTValue.
+        :type request: :class:`tencentcloud.dnspod.v20210323.models.CreateSubdomainValidateTXTValueRequest`
+        :rtype: :class:`tencentcloud.dnspod.v20210323.models.CreateSubdomainValidateTXTValueResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateSubdomainValidateTXTValue", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateSubdomainValidateTXTValueResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def CreateTXTRecord(self, request):
+        """添加TXT记录
+        备注：新添加的解析记录存在短暂的索引延迟，如果查询不到新增记录，请在 30 秒后重试
+
+        :param request: Request instance for CreateTXTRecord.
+        :type request: :class:`tencentcloud.dnspod.v20210323.models.CreateTXTRecordRequest`
+        :rtype: :class:`tencentcloud.dnspod.v20210323.models.CreateTXTRecordResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateTXTRecord", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateTXTRecordResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteDomain(self, request):
         """删除域名
 
@@ -348,6 +513,52 @@ class DnspodClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteDomainCustomLine(self, request):
+        """删除域名的自定义线路
+
+        :param request: Request instance for DeleteDomainCustomLine.
+        :type request: :class:`tencentcloud.dnspod.v20210323.models.DeleteDomainCustomLineRequest`
+        :rtype: :class:`tencentcloud.dnspod.v20210323.models.DeleteDomainCustomLineResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteDomainCustomLine", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteDomainCustomLineResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DeleteLineGroup(self, request):
+        """删除域名的线路分组
+
+        :param request: Request instance for DeleteLineGroup.
+        :type request: :class:`tencentcloud.dnspod.v20210323.models.DeleteLineGroupRequest`
+        :rtype: :class:`tencentcloud.dnspod.v20210323.models.DeleteLineGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteLineGroup", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteLineGroupResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteRecord(self, request):
         """删除记录
 
@@ -373,6 +584,7 @@ class DnspodClient(AbstractClient):
 
     def DeleteRecordBatch(self, request):
         """批量删除解析记录
+        备注：因存储限制， 建议一次批量删除最多2000条
 
         :param request: Request instance for DeleteRecordBatch.
         :type request: :class:`tencentcloud.dnspod.v20210323.models.DeleteRecordBatchRequest`
@@ -418,7 +630,7 @@ class DnspodClient(AbstractClient):
 
 
     def DeleteShareDomain(self, request):
-        """删除域名共享
+        """按账号删除域名共享
 
         :param request: Request instance for DeleteShareDomain.
         :type request: :class:`tencentcloud.dnspod.v20210323.models.DeleteShareDomainRequest`
@@ -464,7 +676,7 @@ class DnspodClient(AbstractClient):
 
 
     def DescribeBatchTask(self, request):
-        """获取任务详情
+        """获取批量操作任务执行详情
 
         :param request: Request instance for DescribeBatchTask.
         :type request: :class:`tencentcloud.dnspod.v20210323.models.DescribeBatchTaskRequest`
@@ -555,8 +767,55 @@ class DnspodClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeDomainAndRecordList(self, request):
+        """批量操作中搜索域名
+
+        :param request: Request instance for DescribeDomainAndRecordList.
+        :type request: :class:`tencentcloud.dnspod.v20210323.models.DescribeDomainAndRecordListRequest`
+        :rtype: :class:`tencentcloud.dnspod.v20210323.models.DescribeDomainAndRecordListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDomainAndRecordList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeDomainAndRecordListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeDomainCustomLineList(self, request):
+        """获取域名的自定义线路列表
+
+        :param request: Request instance for DescribeDomainCustomLineList.
+        :type request: :class:`tencentcloud.dnspod.v20210323.models.DescribeDomainCustomLineListRequest`
+        :rtype: :class:`tencentcloud.dnspod.v20210323.models.DescribeDomainCustomLineListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDomainCustomLineList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeDomainCustomLineListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeDomainFilterList(self, request):
         """获取域名筛选列表
+        备注：新添加的解析记录存在短暂的索引延迟，如果查询不到新增记录，请在 30 秒后重试
 
         :param request: Request instance for DescribeDomainFilterList.
         :type request: :class:`tencentcloud.dnspod.v20210323.models.DescribeDomainFilterListRequest`
@@ -716,6 +975,29 @@ class DnspodClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeDomainShareUserList(self, request):
+        """获取指定域名的已共享列表
+
+        :param request: Request instance for DescribeDomainShareUserList.
+        :type request: :class:`tencentcloud.dnspod.v20210323.models.DescribeDomainShareUserListRequest`
+        :rtype: :class:`tencentcloud.dnspod.v20210323.models.DescribeDomainShareUserListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDomainShareUserList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeDomainShareUserListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeDomainWhois(self, request):
         """获取域名Whois信息
 
@@ -739,6 +1021,52 @@ class DnspodClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeFileInfoByJobId(self, request):
+        """根据批量任务ID获取生成文件信息
+
+        :param request: Request instance for DescribeFileInfoByJobId.
+        :type request: :class:`tencentcloud.dnspod.v20210323.models.DescribeFileInfoByJobIdRequest`
+        :rtype: :class:`tencentcloud.dnspod.v20210323.models.DescribeFileInfoByJobIdResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeFileInfoByJobId", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeFileInfoByJobIdResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeLineGroupList(self, request):
+        """获取域名的线路分组列表
+
+        :param request: Request instance for DescribeLineGroupList.
+        :type request: :class:`tencentcloud.dnspod.v20210323.models.DescribeLineGroupListRequest`
+        :rtype: :class:`tencentcloud.dnspod.v20210323.models.DescribeLineGroupListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeLineGroupList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeLineGroupListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribePackageDetail(self, request):
         """获取各套餐配置详情
 
@@ -810,6 +1138,9 @@ class DnspodClient(AbstractClient):
 
     def DescribeRecordFilterList(self, request):
         """获取某个域名下的解析记录列表
+        备注：
+        1. 新添加的解析记录存在短暂的索引延迟，如果查询不到新增记录，请在 30 秒后重试
+        2.  API获取的记录总条数会比控制台多2条，原因是： 为了防止用户误操作导致解析服务不可用，对2021-10-29 14:24:26之后添加的域名，在控制台都不显示这2条NS记录。
 
         :param request: Request instance for DescribeRecordFilterList.
         :type request: :class:`tencentcloud.dnspod.v20210323.models.DescribeRecordFilterListRequest`
@@ -854,6 +1185,29 @@ class DnspodClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeRecordLineCategoryList(self, request):
+        """按分类返回线路列表
+
+        :param request: Request instance for DescribeRecordLineCategoryList.
+        :type request: :class:`tencentcloud.dnspod.v20210323.models.DescribeRecordLineCategoryListRequest`
+        :rtype: :class:`tencentcloud.dnspod.v20210323.models.DescribeRecordLineCategoryListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeRecordLineCategoryList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeRecordLineCategoryListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeRecordLineList(self, request):
         """获取等级允许的线路
 
@@ -879,6 +1233,9 @@ class DnspodClient(AbstractClient):
 
     def DescribeRecordList(self, request):
         """获取某个域名下的解析记录列表
+        备注：
+        1. 新添加的解析记录存在短暂的索引延迟，如果查询不到新增记录，请在 30 秒后重试
+        2.  API获取的记录总条数会比控制台多2条，原因是： 为了防止用户误操作导致解析服务不可用，对2021-10-29 14:24:26之后添加的域名，在控制台都不显示这2条NS记录。
 
         :param request: Request instance for DescribeRecordList.
         :type request: :class:`tencentcloud.dnspod.v20210323.models.DescribeRecordListRequest`
@@ -1061,8 +1418,31 @@ class DnspodClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeSubdomainValidateStatus(self, request):
+        """查看添加子域名 Zone 域解析 TXT 记录值验证状态
+
+        :param request: Request instance for DescribeSubdomainValidateStatus.
+        :type request: :class:`tencentcloud.dnspod.v20210323.models.DescribeSubdomainValidateStatusRequest`
+        :rtype: :class:`tencentcloud.dnspod.v20210323.models.DescribeSubdomainValidateStatusResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeSubdomainValidateStatus", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeSubdomainValidateStatusResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeUserDetail(self, request):
-        """获取帐户信息
+        """获取账户信息
 
         :param request: Request instance for DescribeUserDetail.
         :type request: :class:`tencentcloud.dnspod.v20210323.models.DescribeUserDetailRequest`
@@ -1130,6 +1510,29 @@ class DnspodClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyDomainCustomLine(self, request):
+        """修改域名的自定义线路
+
+        :param request: Request instance for ModifyDomainCustomLine.
+        :type request: :class:`tencentcloud.dnspod.v20210323.models.ModifyDomainCustomLineRequest`
+        :rtype: :class:`tencentcloud.dnspod.v20210323.models.ModifyDomainCustomLineResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyDomainCustomLine", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyDomainCustomLineResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyDomainLock(self, request):
         """锁定域名
 
@@ -1222,6 +1625,29 @@ class DnspodClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyDomainToGroup(self, request):
+        """修改域名所属分组
+
+        :param request: Request instance for ModifyDomainToGroup.
+        :type request: :class:`tencentcloud.dnspod.v20210323.models.ModifyDomainToGroupRequest`
+        :rtype: :class:`tencentcloud.dnspod.v20210323.models.ModifyDomainToGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyDomainToGroup", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyDomainToGroupResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyDomainUnlock(self, request):
         """域名锁定解锁
 
@@ -1268,6 +1694,29 @@ class DnspodClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyLineGroup(self, request):
+        """修改域名的线路分组
+
+        :param request: Request instance for ModifyLineGroup.
+        :type request: :class:`tencentcloud.dnspod.v20210323.models.ModifyLineGroupRequest`
+        :rtype: :class:`tencentcloud.dnspod.v20210323.models.ModifyLineGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyLineGroup", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyLineGroupResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyPackageAutoRenew(self, request):
         """DNS 解析套餐自动续费设置
 
@@ -1498,6 +1947,29 @@ class DnspodClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyTXTRecord(self, request):
+        """修改TXT记录
+
+        :param request: Request instance for ModifyTXTRecord.
+        :type request: :class:`tencentcloud.dnspod.v20210323.models.ModifyTXTRecordRequest`
+        :rtype: :class:`tencentcloud.dnspod.v20210323.models.ModifyTXTRecordResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyTXTRecord", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyTXTRecordResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyVasAutoRenewStatus(self, request):
         """增值服务自动续费设置
 
