@@ -45,18 +45,24 @@ class LkeapClient(AbstractClient):
             - 支持64K上下文长度，最大输出16k。
         - DeepSeek-R1（model 参数值为**deepseek-r1**）
             - DeepSeek-R1为671B模型，使用强化学习训练，推理过程包含大量反思和验证，思维链长度可达数万字。 该系列模型在数学、代码以及各种复杂逻辑推理任务上推理效果优异，并为用户展现了完整的思考过程。
+            -  支持96K上下文长度，最大输入长度64k，最大输出16k（默认4k），最大思维链输出长度32k。
+        - DeepSeek-Prover-V2（model 参数值为**deepseek-prover-v2**）
+            - DeepSeek-Prover-V2 为671B 参数 MoE 模型，在数学定理证明和复杂计算任务中表现出色。
             -  支持64K上下文长度，最大输出16k。
 
+
         ### 计费说明
 
         - 标准计费（2025年2月26日起生效），计费模式为后付费小时结，为保证您账户资源的正常使用，请提前[开通后付费](https://lke.cloud.tencent.com/lke#/app/system/charge/postpaid)并及时[充值](https://console.cloud.tencent.com/expense/recharge)。
 
-            -   DeepSeek-R1 模型   | 输入：0.004元/千token | 输出（含思维链）：0.016元/千token
+            -  DeepSeek-R1 模型   | 输入：0.004元/千token | 输出（含思维链）：0.016元/千token
 
             - DeepSeek-V3 模型 | 输入：0.002元/千token | 输出：0.008元/千token
 
             - DeepSeek-V3-0324 模型 | 输入：0.002元/千token | 输出：0.008元/千token
 
+            - DeepSeek-Prover-V2 模型 | 暂不计费
+
 
         ### Openai兼容协议接口
         知识引擎原子能力大模型对话 API 兼容了 OpenAI 的接口规范，这意味着您可以直接使用 OpenAI 官方提供的 SDK 来调用大模型对话接口。您仅需要将 base_url 和 [api_key](https://cloud.tencent.com/document/product/1772/115970) 替换成相关配置，不需要对应用做额外修改，即可无缝将您的应用切换到相应的大模型。请参考文档：[Deepseek OpenAI对话接口](https://cloud.tencent.com/document/product/1772/115969)。
@@ -678,6 +684,29 @@ class LkeapClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def RetrieveKnowledgeRealtime(self, request):
+        """用于实时检索在UploadDocRealtime接口上传的实时文档内容。 使用场景：适用于在会话中对文档进行问答的场景
+
+        :param request: Request instance for RetrieveKnowledgeRealtime.
+        :type request: :class:`tencentcloud.lkeap.v20240522.models.RetrieveKnowledgeRealtimeRequest`
+        :rtype: :class:`tencentcloud.lkeap.v20240522.models.RetrieveKnowledgeRealtimeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RetrieveKnowledgeRealtime", params, headers=headers)
+            response = json.loads(body)
+            model = models.RetrieveKnowledgeRealtimeResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def RunRerank(self, request):
         """基于知识引擎精调模型技术的rerank模型，支持对多路召回的结果进行重排序，根据query与切片内容的相关性，按分数由高到低对切片进行排序，并输出对应的打分结果。
 
@@ -718,25 +747,6 @@ class LkeapClient(AbstractClient):
             model = models.UploadDocResponse()
             model._deserialize(response["Response"])
             return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(type(e).__name__, str(e))
-
-
-    def UploadDocRealtime(self, request):
-        """用于上传实时文档内容。
-        实时文档在上传后可以立即通过SearchRealtime进行实时检索，适用于在会话中对文档进行问答的场景。
-
-        :param request: Request instance for UploadDocRealtime.
-        :type request: :class:`tencentcloud.lkeap.v20240522.models.UploadDocRealtimeRequest`
-        :rtype: :class:`tencentcloud.lkeap.v20240522.models.UploadDocRealtimeResponse`
-
-        """
-        try:
-            params = request._serialize()
-            return self._call_and_deserialize("UploadDocRealtime", params, models.UploadDocRealtimeResponse, headers=request.headers)
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
